NHI (The host interface adapter) is allowed to use HopIDs 1-7 as well so
relax the restriction in tb_port_alloc_hopid() to support this.

Signed-off-by: Mika Westerberg <mika.westerb...@linux.intel.com>
---
 drivers/thunderbolt/switch.c | 7 +++++--
 1 file changed, 5 insertions(+), 2 deletions(-)

diff --git a/drivers/thunderbolt/switch.c b/drivers/thunderbolt/switch.c
index d7d60cd9226f..95b75a712ade 100644
--- a/drivers/thunderbolt/switch.c
+++ b/drivers/thunderbolt/switch.c
@@ -789,8 +789,11 @@ static int tb_port_alloc_hopid(struct tb_port *port, bool 
in, int min_hopid,
                ida = &port->out_hopids;
        }
 
-       /* HopIDs 0-7 are reserved */
-       if (min_hopid < TB_PATH_MIN_HOPID)
+       /*
+        * NHI can use HopIDs 1-max for other adapters HopIDs 0-7 are
+        * reserved.
+        */
+       if (port->config.type != TB_TYPE_NHI && min_hopid < TB_PATH_MIN_HOPID)
                min_hopid = TB_PATH_MIN_HOPID;
 
        if (max_hopid < 0 || max_hopid > port_max_hopid)
-- 
2.27.0.rc2

Reply via email to